# Changelog for https://gitlab.com/mbarkhau/pycalver


## v201907.0036

 - Fix: Don't use git/hg command if `commit=False` is configured (thanks @valentin87)


## v201907.0035

 - Fix gitlab#6: Add parts `{month_short}`, `{dom_short}`, `{doy_short}`.
 - Fix gitlab#5: Better warning when using bump with semver (one of --major/--minor/--patch is required)
 - Fix gitlab#4: Make {release} part optional, so that versions generated by --release=final are parsed.


## v201903.0030

 - Fix: Use pattern from config instead of hardcoded {pycalver} pattern.
 - Fix: Better error messages for git/hg issues.
 - Add: Implicit default pattern for config file.


## v201903.0028

 - Fix: Add warnings when configured files are not under version control.
 - Add: Coloured output for bump --dry


## v201902.0027

 - Fix: Allow --release=post
 - Fix: Better error reporting for bad patterns
 - Fix: Regex escaping issue with "?"


## v201902.0024

 - Added: Support for globs in file patterns.
 - Fixed: Better error reporting for invalid config.


## v201902.0020

 - Added: Support for many more custom version patterns.


## v201812.0018

 - Fixed: Better handling of pattern replacements with "-final" releases.


## v201812.0017

 - Fixed github#2. `pycalver init` was broken.
 - Fixed pattern escaping issues.
 - Added lots more tests for cli.
 - Cleaned up documentation.


## v201812.0011-beta

 - Add version tags using git/hg.
 - Use git/hg tags as SSOT for most recent version.
 - Start using https://gitlab.com/mbarkhau/bootstrapit
 - Move to https://gitlab.com/mbarkhau/pycalver


## v201809.0001-alpha

 - Initial release
